==> humhub-1.15.0-beta.1.tar.gz: humhub-1.15.0-beta.1/protected/humhub/modules/admin/messages/ht/space.php <==
<?php

return [
    'Settings' => 'Anviwònman',
    '<strong>Manage</strong> Spaces' => '',
    'Add new space' => '',
    'By using user roles, you can create different permission groups within a Space. These can also be individualized by authorized users for each and every Space and are only relevant for that specific Space.' => '',
    'Change owner' => '',
    'Default "Hide About Page"' => '',
    'Default "Hide Activity Sidebar Widget"' => '',
    'Default "Hide Followers"' => '',
    'Default "Hide Members"' => '',
    'Default Content Visiblity' => '',
    'Default Join Policy' => '',
    'Default Space Permissions' => '',
    'Default Space(s)' => '',
    'Default Visibility' => '',
    'Default homepage' => '',
    'Default homepage (Non-members)' => '',
    'Default space' => '',
    'Here you can define your default settings for new spaces. These settings can be overwritten for each individual space.' => '',
    'Invalid space' => '',
    'Manage members' => '',
    'Manage modules' => '',
    'Open space' => '',
    'Overview' => '',
    'Permissions' => '',
    'Search by name, description, id or owner.' => '',
    'Space Settings' => '',
    'These options allow you to set the default permissions for all Spaces. Authorized users are able individualize these for each Space. Further entries are added with the installation of new modules.' => '',
    'This overview contains a list of each space with actions to view, edit and delete spaces.' => '',
    'Update Space memberships also for existing members.' => '',
];

==> humhub-1.17.0-beta.1.tar.gz: humhub-1.17.0-beta.1/protected/humhub/modules/admin/messages/ht/space.php <==
<?php

return [
    'Settings' => 'Anviwònman',
    '<strong>Manage</strong> Spaces' => '',
    'Add new space' => '',
    'By using user roles, you can create different permission groups within a Space. These can also be individualized by authorized users for each and every Space and are only relevant for that specific Space.' => '',
    'Change owner' => '',
    'Default "Hide About Page"' => '',
    'Default "Hide Activity Sidebar Widget"' => '',
    'Default "Hide Followers"' => '',
    'Default "Hide Members"' => '',
    'Default Content Visiblity' => '',
    'Default Homepage' => '',
    'Default Homepage (Non-members)' => '',
    'Default Join Policy' => '',
    'Default Space Permissions' => '',
    'Default Space(s)' => '',
    'Default Stream Sort' => '',
    'Default Visibility' => '',
    'Default space' => '',
    'Here you can define your default settings for new spaces. These settings can be overwritten for each individual space.' => '',
    'Invalid space' => '',
    'Manage members' => '',
    'Manage modules' => '',
    'Open space' => '',
    'Overview' => '',
    'Permissions' => '',
    'Search by name, description, id or owner.' => '',
    'Space Settings' => '',
    'These options allow you to set the default permissions for all Spaces. Authorized users are able individualize these for each Space. Further entries are added with the installation of new modules.' => '',
    'This overview contains a list of each space with actions to view, edit and delete spaces.' => '',
    'Update Space memberships also for existing members.' => '',
];
